Getting Started with python-cybox
=================================

.. note::

    The python-cybox library is intended for developers who want to add CybOX
    support to existing programs or create new programs that handle CybOX
    content.  Experience with Python development is assumed.

    Other users should look at existing tools_ that support CybOX.

    Understanding XML, XML Schema, and the CybOX language is also
    incredibly helpful when using python-cybox in an application.

.. _tools: https://cyboxproject.github.io/#convert

First, you should follow the :ref:`installation` procedures.


Example Scripts
---------------

The python-cybox repository contains several `example scripts`_ that help
illustrate the capabilities of the APIs. These scripts are simple command line
utilities that can be executed by passing the name of the script to a Python
interpreter.

.. code-block:: bash

    $ python simple_email_instance.py

.. _example scripts: https://github.com/CybOXProject/python-cybox/tree/master/examples


Writing Your Own Application
----------------------------

See the :ref:`examples` page for more examples of using python-cybox in your
own application.
